import numpy as np
import matplotlib.pyplot as plt

plt.rc('font', family='Times New Roman')


def sigmoid(x):
    return 1. / (1 + np.exp(-x))


def relu(x):
    return np.where(x < 0, 0, x)


def cosine(x):
    return 1 - np.cos(x)


def angular(x):
    return np.abs(x)


def plot_sigmoid():
    x = np.linspace(-10, 10, 1000)  # 这个表示在-10到10之间生成1000个x值
    y = sigmoid(x)  # 对上述生成的1000个数循环用sigmoid公式求对应的y
    plt.xlim((-10, 10))
    plt.ylim((0.00, 1.20))
    plt.yticks([0.5, 1.0], [0.5, 1.0])  # 设置y轴显示的刻度
    plt.plot(x, y, color="c", linewidth=2.5)  # 用上述生成的1000个xy值对生成1000个点
    ax = plt.gca()
    ax.spines['right'].set_color('none')  # 删除右边框设为无
    ax.spines['top'].set_color('none')  # 删除上边框设为无
    ax.xaxis.set_ticks_position('bottom')
    ax.spines['bottom'].set_position(('data', 0))  # 调整x轴位置
    ax.yaxis.set_ticks_position('left')
    ax.spines['left'].set_position(('data', 0))  # 调整y轴位置
    plt.savefig("sigmoid.pdf")
    plt.show()


def plot_relu():
    x = np.arange(-10, 10, 0.1)
    y = relu(x)
    # fig = plt.figure()
    ax = plt.gca()
    ax.spines['top'].set_color('none')
    ax.spines['right'].set_color('none')
    # ax.spines['bottom'].set_color('none')
    # ax.spines['left'].set_color('none')
    ax.spines['left'].set_position(('data', 0))
    ax.plot(x, y, color="b", linewidth=2.5)
    plt.xlim([-10.05, 10.05])
    plt.ylim([0, 10.02])
    ax.set_yticks([2, 4, 6, 8, 10])
    plt.tight_layout()
    plt.savefig("relu.pdf")
    plt.show()


def plot_cos():
    x = np.arange(-3, 3, 0.1)
    y = cosine(x)
    # fig = plt.figure()
    ax = plt.gca()
    ax.spines['top'].set_color('none')
    ax.spines['right'].set_color('none')
    # ax.spines['bottom'].set_color('none')
    # ax.spines['left'].set_color('none')
    ax.spines['left'].set_position(('data', 0))
    ax.plot(x, y, color="r", linewidth=2.5)
    plt.xlim([-2.9, 2.9])
    plt.ylim([0, 3])
    ax.set_yticks([1, 2])
    plt.tight_layout()
    plt.savefig("cos.pdf")
    plt.show()


def plot_ang():
    x = np.arange(-3, 3, 0.1)
    y = angular(x)
    # fig = plt.figure()
    ax = plt.gca()
    ax.spines['top'].set_color('none')
    ax.spines['right'].set_color('none')
    # ax.spines['bottom'].set_color('none')
    # ax.spines['left'].set_color('none')
    ax.spines['left'].set_position(('data', 0))
    ax.plot(x, y, color="g", linewidth=2.5)
    plt.xlim([-2.9, 2.9])
    plt.ylim([0, 3])
    ax.set_yticks([1, 2])
    plt.tight_layout()
    plt.savefig("ang.pdf")
    plt.show()


if __name__ == "__main__":
    plt.tick_params(labelsize=20)
    plot_sigmoid()
    plt.tick_params(labelsize=20)
    plot_relu()
    plt.tick_params(labelsize=20)
    plot_cos()
    plt.tick_params(labelsize=20)
    plot_ang()
